@@ -2,7 +2,7 @@ import os
 from logging import getLogger
 from pathlib import Path
 from typing import Self, TypeVar
-from urllib.parse import urlparse, urlunparse
+from urllib.parse import ParseResult, urlparse, urlunparse
 
 import unique_sdk
 from platformdirs import user_config_dir
@@ -99,22 +99,28 @@ class UniqueApi(BaseSettings):
             )
         )
 
-    def sdk_url(self) -> str:
+    def base_path(self) -> tuple[ParseResult, str]:
         parsed = urlparse(self.base_url)
+        base_path = "/public/chat/"
 
-        path = "/public/chat"
         if parsed.hostname and (
-            "qa.unique" in parsed.hostname or ".unique" in parsed.hostname
+            "gateway.qa.unique" in parsed.hostname
+            or "gateway.unique" in parsed.hostname
         ):
-            path = "/public/chat-gen2"
-        return urlunparse(parsed._replace(path=path, query=None, fragment=None))
+            base_path = "/public/chat-gen2/"
+
+        if parsed.hostname and "localhost" in parsed.hostname:
+            base_path = "/public/"
+
+        return parsed, base_path
+
+    def sdk_url(self) -> str:
+        parsed, base_path = self.base_path()
+        return urlunparse(parsed._replace(path=base_path, query=None, fragment=None))
 
     def openai_proxy_url(self) -> str:
-        parsed = urlparse(self.base_url)
-        path = "/public/chat/openai-proxy/"
-        if parsed.hostname and "qa.unique" in parsed.hostname:
-            path = "/public/chat-gen2/openai-proxy/"
-
+        parsed, base_path = self.base_path()
+        path = base_path + "openai-proxy/"
         return urlunparse(parsed._replace(path=path, query=None, fragment=None))
 
 
@@ -152,10 +158,19 @@ class EnvFileNotFoundError(FileNotFoundError):
 
 
 class UniqueSettings:
-    def __init__(self, auth: UniqueAuth, app: UniqueApp, api: UniqueApi):
+    def __init__(
+        self,
+        auth: UniqueAuth,
+        app: UniqueApp,
+        api: UniqueApi,
+        env_file: Path | None = None,
+    ):
         self.app = app
         self.auth = auth
         self.api = api
+        self._env_file: Path | None = (
+            env_file if (env_file and env_file.exists()) else None
+        )
 
     @classmethod
     def _find_env_file(cls, filename: str = "unique.env") -> Path:
@@ -220,7 +235,7 @@ class UniqueSettings:
         auth = UniqueAuth(_env_file=env_file_str)  # type: ignore[call-arg]
         app = UniqueApp(_env_file=env_file_str)  # type: ignore[call-arg]
         api = UniqueApi(_env_file=env_file_str)  # type: ignore[call-arg]
-        return cls(auth=auth, app=app, api=api)
+        return cls(auth=auth, app=app, api=api, env_file=env_file)
 
     @classmethod
     def from_env_auto(cls, filename: str = "unique.env") -> "UniqueSettings":
@@ -237,6 +252,7 @@ class UniqueSettings:
         """
         try:
             env_file = cls._find_env_file(filename)
+            logger.info(f"Environment file found at {env_file}")
             return cls.from_env(env_file=env_file)
         except EnvFileNotFoundError:
             logger.warning(
